==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/pl.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nie można było wysłać wiadomości do następujących użytkowników: %s",
    "Turned on maintenance mode" : "Włączony tryb konserwacji",
    "Turned off maintenance mode" : "Wyłączony tryb konserwacji",
    "Updated database" : "Zaktualizuj bazę",
    "Checked database schema update" : "Sprawdzono aktualizację schematu bazy danych",
    "Checked database schema update for apps" : "Sprawdzono aktualizację schematu bazy danych dla aplikacji",
    "Updated \"%s\" to %s" : "Zaktualizowano \"%s\" do %s",
    "Repair warning: " : "Ostrzeżenie naprawiania:",
    "Repair error: " : "Błąd naprawiania:",
    "Invalid file provided" : "Podano błędny plik",
    "No image or file provided" : "Brak obrazu lub pliku dostarczonego",
    "Unknown filetype" : "Nieznany typ pliku",
    "Invalid image" : "Nieprawidłowe zdjęcie",
    "No temporary profile picture available, try again" : "Brak obrazka profilu tymczasowego, spróbuj ponownie",
    "No crop data provided" : "Brak danych do przycięcia",
    "Couldn't reset password because the token is invalid" : "Nie można zresetować hasła, ponieważ token jest niepoprawny",
    "Couldn't send reset email. Please make sure your username is correct." : "Nie mogę wysłać maila resetującego. Sprawdź czy nazwa użytkownika jest poprawna.",
    "%s password reset" : "%s reset hasła",
    "Couldn't send reset email. Please contact your administrator." : "Nie mogę wysłać maila resetującego. Skontaktuj się z administratorem.",
    "Sunday" : "Niedziela",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Sun." : "N.",
    "Mon." : "Pn.",
    "Tue." : "Wt.",
    "Wed." : "Śr.",
    "Thu." : "Cz.",
    "Fri." : "Pt.",
    "Sat." : "S.",
    "January" : "Styczeń",
    "February" : "Luty",
    "March" : "Marzec",
    "April" : "Kwiecień",
    "May" : "Maj",
    "June" : "Czerwiec",
    "July" : "Lipiec",
    "August" : "Sierpień",
    "September" : "Wrzesień",
    "October" : "Październik",
    "November" : "Listopad",
    "December" : "Grudzień",
    "Jan." : "Sty.",
    "Feb." : "Lut.",
    "Mar." : "Mar.",
    "Apr." : "Kwi.",
    "May." : "Maj.",
    "Jun." : "Cze.",
    "Jul." : "Lip.",
    "Aug." : "Sie.",
    "Sep." : "Wrz.",
    "Oct." : "Paź.",
    "Nov." : "Lis.",
    "Dec." : "Gru.",
    "Settings" : "Ustawienia",
    "Saving..." : "Zapisywanie...",
    "Dismiss" : "Anuluj",
    "seconds ago" : "sekund temu",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link do zresetowanego hasła, został wysłany na twój adres e-mail. Jeśli nie dostałeś wiadomości w rozsądnym czasie, sprawdź folder ze spamem.<br> Jeśli nie ma wiadomości w tym folderze, skontaktuj się ze swoim administratorem.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Twoje pliki są zaszyfrowane. Jeśli nie włączyłeś klucza odzyskiwania, nie będzie możliwości odszyfrowania tych plików po zresetowaniu hasła.<br>Jeśli nie jesteś pewien co zrobić, skontaktuj się ze swoim administratorem, zanim bedziesz kontynuował. <br/> Czy chcesz kontynuować?\n ",
    "I know what I'm doing" : "Wiem co robię",
    "Password can not be changed. Please contact your administrator." : "Hasło nie może zostać zmienione. Skontaktuj się z administratorem.",
    "No" : "Nie",
    "Yes" : "Tak",
    "Choose" : "Wybierz",
    "Error loading file picker template: {error}" : "Błąd podczas ładowania pliku wybranego szablonu: {error}",
    "Ok" : "OK",
    "Error loading message template: {error}" : "Błąd podczas ładowania szablonu wiadomości: {error}",
    "read-only" : "tylko odczyt",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konfliktów plików","{count} konfliktów plików","{count} konfliktów plików"],
    "One file conflict" : "Konflikt pliku",
    "New Files" : "Nowe pliki",
    "Already existing files" : "Już istniejące pliki",
    "Which files do you want to keep?" : "Które pliki chcesz zachować?",
    "If you select both versions, the copied file will have a number added to its name." : "Jeśli wybierzesz obie wersje, skopiowany plik będzie miał dodany numerek w nazwie",
    "Cancel" : "Anuluj",
    "Continue" : "Kontynuuj ",
    "(all selected)" : "(wszystkie zaznaczone)",
    "({count} selected)" : "({count} zaznaczonych)",
    "Error loading file exists template" : "Błąd podczas ładowania szablonu istniejącego pliku",
    "Very weak password" : "Bardzo słabe hasło",
    "Weak password" : "Słabe hasło",
    "So-so password" : "Mało skomplikowane hasło",
    "Good password" : "Dobre hasło",
    "Strong password" : "Mocne hasło",
    "Error occurred while checking server setup" : "Pojawił się błąd podczas sprawdzania ustawień serwera",
    "Shared" : "Udostępniono",
    "Shared with {recipients}" : "Współdzielony z {recipients}",
    "Error" : "Błąd",
    "Error while sharing" : "Błąd podczas współdzielenia",
    "Error while unsharing" : "Błąd podczas zatrzymywania współdzielenia",
    "Error setting expiration date" : "Błąd podczas ustawiania daty wygaśnięcia",
    "The public link will expire no later than {days} days after it is created" : "Link publiczny wygaśnie nie później niż po {days} dniach od utworzenia",
    "Set expiration date" : "Ustaw datę wygaśnięcia",
    "Expiration" : "Wygaśnięcie",
    "Expiration date" : "Data wygaśnięcia",
    "Choose a password for the public link" : "Wybierz hasło dla linku publicznego",
    "Sending ..." : "Wysyłanie...",
    "Email sent" : "E-mail wysłany",
    "Resharing is not allowed" : "Współdzielenie nie jest możliwe",
    "Share link" : "Udostępnij link",
    "Link" : "Odnośnik",
    "Password protect" : "Zabezpiecz hasłem",
    "Password" : "Hasło",
    "Allow editing" : "Pozwól na edycję",
    "Email link to person" : "Wyślij osobie odnośnik poprzez e-mail",
    "Send" : "Wyślij",
    "Shared with you and the group {group} by {owner}" : "Udostępnione tobie i grupie {group} przez {owner}",
    "Shared with you by {owner}" : "Udostępnione tobie przez {owner}",
    "group" : "grupa",
    "remote" : "zdalny",
    "notify by email" : "powiadom przez emaila",
    "Unshare" : "Zatrzymaj współdzielenie",
    "can share" : "może współdzielić",
    "can edit" : "może edytować",
    "create" : "utwórz",
    "change" : "zmiany",
    "delete" : "usuń",
    "access control" : "kontrola dostępu",
    "Share" : "Udostępnij",
    "Share with users or groups …" : "Współdziel z użytkownikami lub grupami",
    "Warning" : "Ostrzeżenie",
    "Delete" : "Usuń",
    "Rename" : "Zmień nazwę",
    "The object type is not specified." : "Nie określono typu obiektu.",
    "Enter new" : "Wpisz nowy",
    "Add" : "Dodaj",
    "Edit tags" : "Edytuj tagi",
    "Error loading dialog template: {error}" : "Błąd podczas ładowania szablonu dialogu: {error}",
    "No tags selected for deletion." : "Nie zaznaczono tagów do usunięcia.",
    "unknown text" : "nieznany tekst",
    "Hello world!" : "Witaj świecie!",
    "sunny" : "słoneczna",
    "Hello {name}, the weather is {weather}" : "Cześć {name}, dzisiejsza pogoda jest {weather}",
    "Hello {name}" : "Witaj {name}",
    "_download %n file_::_download %n files_" : ["pobrano %n plik","pobrano %n plików","pobrano %n plików"],
    "Updating {productName} to version {version}, this may take a while." : "Aktualizuję {productName} do wersji {version}, to może chwilę potrwać.",
    "Please reload the page." : "Proszę przeładować stronę",
    "The update was unsuccessful. " : "Aktualizowanie zakończyło się niepowodzeniem.",
    "The update was successful. Redirecting you to ownCloud now." : "Aktualizacji zakończyła się powodzeniem. Przekierowuję do ownCloud.",
    "Searching other places" : "Przeszukaj inne miejsca",
    "Personal" : "Osobiste",
    "Users" : "Użytkownicy",
    "Apps" : "Aplikacje",
    "Admin" : "Administrator",
    "Help" : "Pomoc",
    "Error loading tags" : "Błąd ładowania tagów",
    "Tag already exists" : "Tag już istnieje",
    "Error deleting tag(s)" : "Błąd przy osuwaniu tag(ów)",
    "Error tagging" : "Błąd tagowania",
    "Error untagging" : "Błąd odtagowania",
    "Error favoriting" : "Błąd podczas dodawania do ulubionch",
    "Error unfavoriting" : "Błąd przy usuwaniu z ulubionych",
    "Access forbidden" : "Dostęp zabroniony",
    "File not found" : "Nie odnaleziono pliku",
    "The specified document has not been found on the server." : "Wskazany dokument nie został znaleziony na serwerze.",
    "You can click here to return to %s." : "Możesz kliknąć tutaj aby powrócić do %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Witaj,\n\ntylko informuję, że %s współdzieli z Tobą %s.\nZobacz tutaj: %s\n\n",
    "The share will expire on %s." : "Ten zasób wygaśnie %s",
    "Cheers!" : "Pozdrawiam!",
    "Internal Server Error" : "Internal Server Error",
    "The server encountered an internal error and was unable to complete your request." : "Serwer napotkał błąd wewnętrzny i nie był w stanie ukończyć Twojego żądania.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Proszę skontaktować się z administratorem jeśli ten błąd będzie się pojawiał wielokrotnie, proszę do zgłoszenia dołączyć szczegóły techniczne opisane poniżej.",
    "More details can be found in the server log." : "Więcej szczegółów można znaleźć w logu serwera.",
    "Technical details" : "Szczegóły techniczne",
    "Remote Address: %s" : "Adres zdalny: %s",
    "Request ID: %s" : "ID żądania: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Komunikat: %s",
    "File: %s" : "Plik: %s",
    "Line: %s" : "Linia: %s",
    "Trace" : "Ślad",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Twój katalog danych i pliki są prawdopodobnie dostępne z poziomu internetu, ponieważ plik .htaccess nie działa.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Aby uzyskać informacje jak poprawnie skonfigurować swój serwer, zapoznaj się z <a href=\"%s\" target=\"_blank\">dokumentacją</a>.",
    "Create an <strong>admin account</strong>" : "Utwórz <strong>konta administratora</strong>",
    "Username" : "Nazwa użytkownika",
    "Storage & database" : "Zasoby dysku & baza danych",
    "Data folder" : "Katalog danych",
    "Configure the database" : "Skonfiguruj bazę danych",
    "Only %s is available." : "Dostępne jest wyłącznie %s.",
    "Database user" : "Użytkownik bazy danych",
    "Database password" : "Hasło do bazy danych",
    "Database name" : "Nazwa bazy danych",
    "Database tablespace" : "Obszar tabel bazy danych",
    "Database host" : "Komputer bazy danych",
    "Finish setup" : "Zakończ konfigurowanie",
    "Finishing …" : "Kończę ...",
    "Need help?" : "Potrzebujesz pomocy?",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Witam, <br><br>informuję, że %s udostępnianych zasobów <strong>%s</strong> jest z Tobą.<br><a href=\"%s\">Zobacz!</a><br><br>",
    "Log out" : "Wyloguj",
    "Search" : "Wyszukaj",
    "Server side authentication failed!" : "Uwierzytelnianie po stronie serwera nie powiodło się!",
    "Please contact your administrator." : "Skontaktuj się z administratorem",
    "Please try again or contact your administrator." : "Spróbuj ponownie lub skontaktuj się z administratorem.",
    "Log in" : "Zaloguj",
    "Alternative Logins" : "Alternatywne loginy",
    "Use the following link to reset your password: {link}" : "Użyj tego odnośnika by zresetować hasło: {link}",
    "New password" : "Nowe hasło",
    "New Password" : "Nowe hasło",
    "Reset password" : "Zresetuj hasło",
    "This ownCloud instance is currently in single user mode." : "Ta instalacja ownCloud działa obecnie w trybie pojedynczego użytkownika.",
    "This means only administrators can use the instance." : "To oznacza, że tylko administratorzy mogą w tej chwili używać aplikacji.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Skontaktuj się z administratorem, jeśli ten komunikat pojawił się nieoczekiwanie lub wyświetla się ciągle.",
    "Thank you for your patience." : "Dziękuję za cierpliwość.",
    "You are accessing the server from an untrusted domain." : "Dostajesz się do serwera z niezaufanej domeny.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "W zależności od konfiguracji, jako administrator możesz także użyć poniższego przycisku aby zaufać tej domenie.",
    "Add \"%s\" as trusted domain" : "Dodaj \"%s\" jako domenę zaufaną",
    "The theme %s has been disabled." : "Motyw %s został wyłączony.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Proszę się upewnić, że baza danych, folder konfiguracji oraz folder danych zostały zarchiwizowane przed przejściem dalej.",
    "Start update" : "Rozpocznij aktualizację",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby uniknąć timeout-ów przy większych instalacjach, możesz zamiast tego uruchomić następującą komendę w katalogu Twojej instalacji:",
    "This page will refresh itself when the %s instance is available again." : "Strona odświeży się gdy instancja %s będzie ponownie dostępna."
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/pl.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nie można było wysłać wiadomości do następujących użytkowników: %s",
    "Turned on maintenance mode" : "Włączony tryb konserwacji",
    "Turned off maintenance mode" : "Wyłączony tryb konserwacji",
    "Updated database" : "Zaktualizuj bazę",
    "Checked database schema update" : "Sprawdzono aktualizację schematu bazy danych",
    "Checked database schema update for apps" : "Sprawdzono aktualizację schematu bazy danych dla aplikacji",
    "Updated \"%s\" to %s" : "Zaktualizowano \"%s\" do %s",
    "Repair warning: " : "Ostrzeżenie naprawiania:",
    "Repair error: " : "Błąd naprawiania:",
    "Invalid file provided" : "Podano błędny plik",
    "No image or file provided" : "Brak obrazu lub pliku dostarczonego",
    "Unknown filetype" : "Nieznany typ pliku",
    "Invalid image" : "Nieprawidłowe zdjęcie",
    "No temporary profile picture available, try again" : "Brak obrazka profilu tymczasowego, spróbuj ponownie",
    "No crop data provided" : "Brak danych do przycięcia",
    "Couldn't reset password because the token is invalid" : "Nie można zresetować hasła, ponieważ token jest niepoprawny",
    "Couldn't send reset email. Please make sure your username is correct." : "Nie mogę wysłać maila resetującego. Sprawdź czy nazwa użytkownika jest poprawna.",
    "%s password reset" : "%s reset hasła",
    "Couldn't send reset email. Please contact your administrator." : "Nie mogę wysłać maila resetującego. Skontaktuj się z administratorem.",
    "Sunday" : "Niedziela",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Sun." : "N.",
    "Mon." : "Pn.",
    "Tue." : "Wt.",
    "Wed." : "Śr.",
    "Thu." : "Cz.",
    "Fri." : "Pt.",
    "Sat." : "S.",
    "January" : "Styczeń",
    "February" : "Luty",
    "March" : "Marzec",
    "April" : "Kwiecień",
    "May" : "Maj",
    "June" : "Czerwiec",
    "July" : "Lipiec",
    "August" : "Sierpień",
    "September" : "Wrzesień",
    "October" : "Październik",
    "November" : "Listopad",
    "December" : "Grudzień",
    "Jan." : "Sty.",
    "Feb." : "Lut.",
    "Mar." : "Mar.",
    "Apr." : "Kwi.",
    "May." : "Maj.",
    "Jun." : "Cze.",
    "Jul." : "Lip.",
    "Aug." : "Sie.",
    "Sep." : "Wrz.",
    "Oct." : "Paź.",
    "Nov." : "Lis.",
    "Dec." : "Gru.",
    "Settings" : "Ustawienia",
    "Saving..." : "Zapisywanie...",
    "Dismiss" : "Anuluj",
    "seconds ago" : "sekund temu",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link do zresetowanego hasła, został wysłany na twój adres e-mail. Jeśli nie dostałeś wiadomości w rozsądnym czasie, sprawdź folder ze spamem.<br> Jeśli nie ma wiadomości w tym folderze, skontaktuj się ze swoim administratorem.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Twoje pliki są zaszyfrowane. Jeśli nie włączyłeś klucza odzyskiwania, nie będzie możliwości odszyfrowania tych plików po zresetowaniu hasła.<br>Jeśli nie jesteś pewien co zrobić, skontaktuj się ze swoim administratorem, zanim bedziesz kontynuował. <br/> Czy chcesz kontynuować?\n ",
    "I know what I'm doing" : "Wiem co robię",
    "Password can not be changed. Please contact your administrator." : "Hasło nie może zostać zmienione. Skontaktuj się z administratorem.",
    "No" : "Nie",
    "Yes" : "Tak",
    "Choose" : "Wybierz",
    "Error loading file picker template: {error}" : "Błąd podczas ładowania pliku wybranego szablonu: {error}",
    "Ok" : "OK",
    "Error loading message template: {error}" : "Błąd podczas ładowania szablonu wiadomości: {error}",
    "read-only" : "tylko odczyt",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konfliktów plików","{count} konfliktów plików","{count} konfliktów plików"],
    "One file conflict" : "Konflikt pliku",
    "New Files" : "Nowe pliki",
    "Already existing files" : "Już istniejące pliki",
    "Which files do you want to keep?" : "Które pliki chcesz zachować?",
    "If you select both versions, the copied file will have a number added to its name." : "Jeśli wybierzesz obie wersje, skopiowany plik będzie miał dodany numerek w nazwie",
    "Cancel" : "Anuluj",
    "Continue" : "Kontynuuj ",
    "(all selected)" : "(wszystkie zaznaczone)",
    "({count} selected)" : "({count} zaznaczonych)",
    "Error loading file exists template" : "Błąd podczas ładowania szablonu istniejącego pliku",
    "Very weak password" : "Bardzo słabe hasło",
    "Weak password" : "Słabe hasło",
    "So-so password" : "Mało skomplikowane hasło",
    "Good password" : "Dobre hasło",
    "Strong password" : "Mocne hasło",
    "Error occurred while checking server setup" : "Pojawił się błąd podczas sprawdzania ustawień serwera",
    "Shared" : "Udostępniono",
    "Shared with {recipients}" : "Współdzielony z {recipients}",
    "Error" : "Błąd",
    "Error while sharing" : "Błąd podczas współdzielenia",
    "Error while unsharing" : "Błąd podczas zatrzymywania współdzielenia",
    "Error setting expiration date" : "Błąd podczas ustawiania daty wygaśnięcia",
    "The public link will expire no later than {days} days after it is created" : "Link publiczny wygaśnie nie później niż po {days} dniach od utworzenia",
    "Set expiration date" : "Ustaw datę wygaśnięcia",
    "Expiration" : "Wygaśnięcie",
    "Expiration date" : "Data wygaśnięcia",
    "Choose a password for the public link" : "Wybierz hasło dla linku publicznego",
    "Sending ..." : "Wysyłanie...",
    "Email sent" : "E-mail wysłany",
    "Resharing is not allowed" : "Współdzielenie nie jest możliwe",
    "Share link" : "Udostępnij link",
    "Link" : "Odnośnik",
    "Password protect" : "Zabezpiecz hasłem",
    "Password" : "Hasło",
    "Allow editing" : "Pozwól na edycję",
    "Email link to person" : "Wyślij osobie odnośnik poprzez e-mail",
    "Send" : "Wyślij",
    "Shared with you and the group {group} by {owner}" : "Udostępnione tobie i grupie {group} przez {owner}",
    "Shared with you by {owner}" : "Udostępnione tobie przez {owner}",
    "group" : "grupa",
    "remote" : "zdalny",
    "notify by email" : "powiadom przez emaila",
    "Unshare" : "Zatrzymaj współdzielenie",
    "can share" : "może współdzielić",
    "can edit" : "może edytować",
    "create" : "utwórz",
    "change" : "zmiany",
    "delete" : "usuń",
    "access control" : "kontrola dostępu",
    "Share" : "Udostępnij",
    "Share with users or groups …" : "Współdziel z użytkownikami lub grupami",
    "Warning" : "Ostrzeżenie",
    "Delete" : "Usuń",
    "Rename" : "Zmień nazwę",
    "The object type is not specified." : "Nie określono typu obiektu.",
    "Enter new" : "Wpisz nowy",
    "Add" : "Dodaj",
    "Edit tags" : "Edytuj tagi",
    "Error loading dialog template: {error}" : "Błąd podczas ładowania szablonu dialogu: {error}",
    "No tags selected for deletion." : "Nie zaznaczono tagów do usunięcia.",
    "unknown text" : "nieznany tekst",
    "Hello world!" : "Witaj świecie!",
    "sunny" : "słoneczna",
    "Hello {name}, the weather is {weather}" : "Cześć {name}, dzisiejsza pogoda jest {weather}",
    "Hello {name}" : "Witaj {name}",
    "_download %n file_::_download %n files_" : ["pobrano %n plik","pobrano %n plików","pobrano %n plików"],
    "Updating {productName} to version {version}, this may take a while." : "Aktualizuję {productName} do wersji {version}, to może chwilę potrwać.",
    "Please reload the page." : "Proszę przeładować stronę",
    "The update was unsuccessful. " : "Aktualizowanie zakończyło się niepowodzeniem.",
    "The update was successful. Redirecting you to ownCloud now." : "Aktualizacji zakończyła się powodzeniem. Przekierowuję do ownCloud.",
    "Searching other places" : "Przeszukaj inne miejsca",
    "Personal" : "Osobiste",
    "Users" : "Użytkownicy",
    "Apps" : "Aplikacje",
    "Admin" : "Administrator",
    "Help" : "Pomoc",
    "Error loading tags" : "Błąd ładowania tagów",
    "Tag already exists" : "Tag już istnieje",
    "Error deleting tag(s)" : "Błąd przy osuwaniu tag(ów)",
    "Error tagging" : "Błąd tagowania",
    "Error untagging" : "Błąd odtagowania",
    "Error favoriting" : "Błąd podczas dodawania do ulubionch",
    "Error unfavoriting" : "Błąd przy usuwaniu z ulubionych",
    "Access forbidden" : "Dostęp zabroniony",
    "File not found" : "Nie odnaleziono pliku",
    "The specified document has not been found on the server." : "Wskazany dokument nie został znaleziony na serwerze.",
    "You can click here to return to %s." : "Możesz kliknąć tutaj aby powrócić do %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Witaj,\n\ntylko informuję, że %s współdzieli z Tobą %s.\nZobacz tutaj: %s\n\n",
    "The share will expire on %s." : "Ten zasób wygaśnie %s",
    "Cheers!" : "Pozdrawiam!",
    "Internal Server Error" : "Internal Server Error",
    "The server encountered an internal error and was unable to complete your request." : "Serwer napotkał błąd wewnętrzny i nie był w stanie ukończyć Twojego żądania.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Proszę skontaktować się z administratorem jeśli ten błąd będzie się pojawiał wielokrotnie, proszę do zgłoszenia dołączyć szczegóły techniczne opisane poniżej.",
    "More details can be found in the server log." : "Więcej szczegółów można znaleźć w logu serwera.",
    "Technical details" : "Szczegóły techniczne",
    "Remote Address: %s" : "Adres zdalny: %s",
    "Request ID: %s" : "ID żądania: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Komunikat: %s",
    "File: %s" : "Plik: %s",
    "Line: %s" : "Linia: %s",
    "Trace" : "Ślad",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Twój katalog danych i pliki są prawdopodobnie dostępne z poziomu internetu, ponieważ plik .htaccess nie działa.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Aby uzyskać informacje jak poprawnie skonfigurować swój serwer, zapoznaj się z <a href=\"%s\" target=\"_blank\">dokumentacją</a>.",
    "Create an <strong>admin account</strong>" : "Utwórz <strong>konta administratora</strong>",
    "Username" : "Nazwa użytkownika",
    "Storage & database" : "Zasoby dysku & baza danych",
    "Data folder" : "Katalog danych",
    "Configure the database" : "Skonfiguruj bazę danych",
    "Only %s is available." : "Dostępne jest wyłącznie %s.",
    "Database user" : "Użytkownik bazy danych",
    "Database password" : "Hasło do bazy danych",
    "Database name" : "Nazwa bazy danych",
    "Database tablespace" : "Obszar tabel bazy danych",
    "Database host" : "Komputer bazy danych",
    "Finish setup" : "Zakończ konfigurowanie",
    "Finishing …" : "Kończę ...",
    "Need help?" : "Potrzebujesz pomocy?",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Witam, <br><br>informuję, że %s udostępnianych zasobów <strong>%s</strong> jest z Tobą.<br><a href=\"%s\">Zobacz!</a><br><br>",
    "Log out" : "Wyloguj",
    "Search" : "Wyszukaj",
    "Server side authentication failed!" : "Uwierzytelnianie po stronie serwera nie powiodło się!",
    "Please contact your administrator." : "Skontaktuj się z administratorem",
    "Please try again or contact your administrator." : "Spróbuj ponownie lub skontaktuj się z administratorem.",
    "Log in" : "Zaloguj",
    "Alternative Logins" : "Alternatywne loginy",
    "Use the following link to reset your password: {link}" : "Użyj tego odnośnika by zresetować hasło: {link}",
    "New password" : "Nowe hasło",
    "New Password" : "Nowe hasło",
    "Reset password" : "Zresetuj hasło",
    "This ownCloud instance is currently in single user mode." : "Ta instalacja ownCloud działa obecnie w trybie pojedynczego użytkownika.",
    "This means only administrators can use the instance." : "To oznacza, że tylko administratorzy mogą w tej chwili używać aplikacji.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Skontaktuj się z administratorem, jeśli ten komunikat pojawił się nieoczekiwanie lub wyświetla się ciągle.",
    "Thank you for your patience." : "Dziękuję za cierpliwość.",
    "You are accessing the server from an untrusted domain." : "Dostajesz się do serwera z niezaufanej domeny.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "W zależności od konfiguracji, jako administrator możesz także użyć poniższego przycisku aby zaufać tej domenie.",
    "Add \"%s\" as trusted domain" : "Dodaj \"%s\" jako domenę zaufaną",
    "The theme %s has been disabled." : "Motyw %s został wyłączony.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Proszę się upewnić, że baza danych, folder konfiguracji oraz folder danych zostały zarchiwizowane przed przejściem dalej.",
    "Start update" : "Rozpocznij aktualizację",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby uniknąć timeout-ów przy większych instalacjach, możesz zamiast tego uruchomić następującą komendę w katalogu Twojej instalacji:",
    "This page will refresh itself when the %s instance is available again." : "Strona odświeży się gdy instancja %s będzie ponownie dostępna.",
    "Error loading file picker template: {error}" : "Błąd podczas ładowania pliku wybranego szablonu: {error}",
    "Following apps have been disabled: %s" : "Poniższe aplikacje zostały wyłączone: %s",
    "Fr" : "Pt",
    "Password can not be changed. Please contact your administrator." : "Hasło nie może zostać zmienione. Skontaktuj się z administratorem.",
    "Sa" : "So",
    "Su" : "Nd",
    "Th" : "Czw",
    "Tu" : "Wt",
    "We" : "Śr"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
